pub fn parse_module_bounded(src: &str, nesting_limit: usize) -> Result<Module>
Parse with a nesting limit of your own, for a caller whose stack is smaller than DEFAULT_NESTING_LIMIT assumes.
DEFAULT_NESTING_LIMIT